/*
 *  Copyright (c) 2017 - present, Architecode Corporation. All Rights Reserved.
 *
 *  This source code is licensed under the MIT License.
 *  The LICENSE file can be found in the root directory.
 *
 *  @cix-lic
*/


"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const logger_registry_1 = require("../core/logger.registry");
class LoggerService {
    constructor(options = {}) {
        Object.defineProperties(this, {
            "Registry": {
                configurable: false,
                enumerable: false,
                writable: false,
                value: new logger_registry_1.LoggerRegistry(options)
            },
        });
    }
    configure(configs = {}) {
        if (configs.defaultLogger) {
            this.setDefaultLogger(configs.defaultLogger.logger, configs.defaultLogger.properties);
        }
        if (Array.isArray(configs.loggerModules)) {
            configs.loggerModules.forEach(each => this.setLoggerModule(each.logger, each.LoggerModule));
        }
        if (Array.isArray(configs.loggerSetups)) {
            configs.loggerSetups.forEach(each => this.setLoggerSetup(each.name, each.type, each.logger, each.properties));
        }
    }
    getDefaultLogger() {
        return this.Registry.getDefaultLogger();
    }
    setDefaultLogger(logger, properties) {
        this.Registry.setDefaultLogger(logger, properties);
    }
    getLoggerModule(logger) {
        return this.Registry.getLoggerModule(logger);
    }
    setLoggerModule(logger, LoggerModule) {
        this.Registry.setLoggerModule(logger, LoggerModule);
    }
    hasLoggerModule(logger) {
        return this.Registry.hasLoggerModule(logger);
    }
    getLoggerSetup(name, type) {
        return this.Registry.getLoggerSetup(name, type);
    }
    setLoggerSetup(name, type, logger, properties) {
        this.Registry.setLoggerSetup(name, type, logger, properties);
    }
    hasLoggerSetup(name, type) {
        return this.Registry.hasLoggerSetup(name, type);
    }
    resolveDefaultLogger(properties) {
        return this.Registry.resolveDefaultLogger(properties);
    }
    resolveLogger(name, type) {
        return this.Registry.resolveLogger(name, type);
    }
}
exports.LoggerService = LoggerService;
